@@ -1,5 +1,5 @@
 package Selenium::CanStartBinary;
-$Selenium::CanStartBinary::VERSION = '1.28';
+$Selenium::CanStartBinary::VERSION = '1.30';
 use strict;
 use warnings;
 
@@ -346,7 +346,7 @@ Selenium::CanStartBinary - Teach a WebDriver how to start its own binary aka no
 
 =head1 VERSION
 
-version 1.28
+version 1.30
 
 =head1 DESCRIPTION
 
@@ -521,7 +521,7 @@ L<Selenium::PhantomJS|Selenium::PhantomJS>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/teodesian/Selenium-Remote-Driver/issues>
+https://github.com/teodesian/Selenium-Remote-Driver/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
